library(gnlm)
library(repeated)

data <- read.table("cream.dat",skip=4,head=T)
attach(data)
resp <- cbind(Favourable,Unfavourable)
treat <- as.numeric(Treatment=="Drug")

glm(resp~Treatment*as.factor(Clinic),family=binomial)
print(summary(z1 <- glm(resp~Treatment+as.factor(Clinic),family=binomial)))
z1$aic/2
print(z0 <- glm(resp~as.factor(Clinic),family=binomial))
z0$aic/2
glm(resp~Treatment,family=binomial)
glm(resp~1,family=binomial)

summary(glmm(resp~Treatment,nest=Clinic,family=binomial,points=12))
glmm(resp~1,nest=Clinic,family=binomial,points=12)

summary(glmm(resp~Treatment,nest=1:16,family=binomial,points=20))
glmm(resp~1,nest=1:16,family=binomial,points=20)

mu <- function(p,linear) exp(linear)/(1+exp(linear))
gnlr(resp,"binomial",mu=mu,pmu=z0$coef,linear=~as.factor(Clinic))
gnlr(resp,"binomial",mu=mu,pmu=z1$coef,linear=~Treatment+as.factor(Clinic))
gnlr(resp,"beta binomial",mu=mu,pmu=z1$coef[1:2],pshape=4,linear=~Treatment)
gnlr(resp,"beta binomial",mu=mu,pmu=z0$coef[1],pshape=10,linear=~1)
gnlr(resp,"beta binomial",mu=mu,pmu=z1$coef,pshape=4,
	linear=~Treatment+as.factor(Clinic))
gnlr(resp,"beta binomial",mu=mu,pmu=z0$coef,pshape=10,
	linear=~as.factor(Clinic))

gnlmm(resp,"binomial",mu=mu,linear=~1,pmu=-1.5,psd=1.2,nest=1:16)
gnlmm(resp,"binomial",mu=mu,linear=~treat,pmu=z1$coef[1:2],psd=1.4,nest=1:16)

yy <- c(Favourable,Unfavourable)
tr <- rep(Treatment,2)
res <- gl(2,16,32)
clinic <- gl(8,2,32)
print(z <- glm(yy~res+clinic*tr,family=poisson))
z$aic/2
print(z <- glm(yy~tr*res+clinic*tr,family=poisson))
z$aic/2
print(z <- glm(yy~res*clinic+clinic*tr,family=poisson))
z$aic/2
print(z <- glm(yy~res*(clinic+tr)+clinic*tr,family=poisson))
z$aic/2

print(z <- glmm(yy~tr+res,family=poisson,nest=rep(Clinic,2),points=5))
z$aic/2
print(summary(z <- glmm(yy~tr*res,family=poisson,nest=rep(Clinic,2),points=5)))
z$aic/2

y <- cbind(Favourable[1:8],Unfavourable[1:8],Favourable[9:16],
	Unfavourable[9:16])
result <- c(0,1,0,1)
treat <- c(0,0,1,1)
tvc1 <- list()
for(i in 1:8){
	tvc1 <- c(tvc1,list(cbind(result,treat)))
	colnames(tvc1[[i]]) <- c("result","treatment")}
tvc1 <- tvctomat(tvc1)
tvc2 <- list()
for(i in 1:8){
	tvc2 <- c(tvc2,list(cbind(result,treat,result*treat)))
	colnames(tvc2[[i]]) <- c("result","treatment","result.treatment")}
tvc2 <- tvctomat(tvc2)
kalcount(y,preg=-2,pinit=4.5,dep="frailty")
kalcount(y,tvcov=tvc1,preg=-2.5,ptvc=c(0,0.3),pinit=13,dep="frailty")
kalcount(y,tvcov=tvc2,preg=-2.5,ptvc=c(0,0.3,0),pinit=13,dep="frailty")

print(z <- glmm(yy~tr+res,family=poisson,nest=gl(16,2),points=5))
z$aic/2
print(summary(z <- glmm(yy~tr*res,family=poisson,nest=gl(16,2),points=5)))
z$aic/2

y2 <- cbind(Favourable[1:16],Unfavourable[1:16])
result2 <- c(0,1)
treat2 <- c(rep(0,8),rep(1,8))
tvc3 <- list()
for(i in 1:16)tvc3 <- c(list(matrix(result2,ncol=1)),tvc3)
colnames(tvc3[[1]]) <- c("result")
tvc3 <- tvctomat(tvc3)
kalcount(y2,ccov=treat2,preg=c(-2,0),pinit=4.5,dep="frailty")
kalcount(y2,ccov=treat2,tvcov=tvc3,preg=c(-2.5,1),ptvc=0,pinit=13,dep="frailty")
