library(gnlm)
library(repeated)

y <- read.table("fabric.dat",skip=2)
colnames(y) <- c("lengths","faults")
attach(y)

glm(faults~1,fam=poisson)
glm(faults~lengths,fam=poisson)
glm(faults~log(lengths),fam=poisson)

if(interactive()){
postscript("fabric.eps",height=5)
plot(lengths,faults,xlim=c(0,1000),ylim=c(0,30),xlab="Length",
	ylab="Number of faults")
lines(seq(120,960,by=40),exp(0.9718+0.0019*seq(120,960,by=40)))
}

mu <- function(p,linear) exp(linear)
print(zp0 <- gnlr(faults,"Poisson",mu=mu,linear=~1,pmu=1))
print(zp1 <- gnlr(faults,"Poisson",mu=mu,linear=~lengths,pmu=c(1,0.002)))
gnlr(faults,"negative binomial",mu=mu,linear=~lengths,pmu=c(1,0.002),psh=1)
shape <- function(p,mu) p[1]+log(mu)
gnlr(faults,"negative binomial",mu=mu,linear=~lengths,pmu=c(1,0.002),
	shape=shape,psh=1,shfn=T)
gnlr(faults,"negative binomial",mu=mu,linear=~1,pmu=8,shape=shape,
	psh=1,shfn=T)

glmm(faults~1,nest=1:length(faults),family=poisson)
glmm(faults~lengths,nest=1:length(faults),family=poisson,points=7)

gnlmm(faults,"Poisson",mu=mu,linear=~1,pmu=zp0$coef,nest=1:length(faults),
	psd=0.33)
gnlmm(faults,"Poisson",mu=mu,linear=~lengths,pmu=zp1$coef,psd=0.33,
	nest=1:length(faults),points=7)
