library(gnlm)
library(repeated)

y <- read.table("fabric.dat",skip=2)
colnames(y) <- c("lengths","faults")
attach(y)

print(zl <- glm(faults~lengths,fam=poisson))
zl$aic/2
print(zll <- glm(faults~log(lengths),fam=poisson))
zll$aic/2
print(z0 <- glm(faults~1,fam=poisson))
z0$aic/2

if(interactive()){
postscript("fabric.eps",height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(lengths,faults,xlim=c(0,1000),ylim=c(0,30),xlab="Length",
	ylab="Number of faults",pch=20,yaxt="n")
axis(2,c(0,10,20,30))
lines(seq(120,960,by=40),exp(0.9718+0.0019*seq(120,960,by=40)))
dev.off()
}

mu <- function(p,linear) exp(linear)
shape <- function(p,mu) p[1]+log(mu)
gnlr(faults,"negative binomial",mu=mu,linear=~lengths,pmu=c(1,0.002),
	shape=shape,psh=1,shfn=T)
print(zm <- glmm(faults~lengths,nest=1:length(faults),family=poisson,points=7))
zm$aic/2
print(zm0 <- glmm(faults~1,nest=1:length(faults),family=poisson))
zm0$aic/2
