library(gnlm)
library(repeated)

data <- read.table("galapago.dat",skip=6)
names(data) <- c("number","native","area","elevation","nearest","santacruz","adjacent")
attach(data)
wt <- rep(1,length(native))
wt[1] <- wt[5] <- wt[7] <- wt[9] <- wt[21] <- wt[28] <- 0

if(interactive()){
postscript(file="galapag.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(area,elevation,xlim=c(0,5000),ylim=c(0,2000),xlab="Area",
	ylab="Elevation",pch=20)
dev.off()
}

print(z0 <- glm(native~1,fam=poisson,weight=wt))
z0$aic/2
print(zf <- glm(native~gl(30,1,30),fam=poisson,weight=wt))
zf$aic/2
print(z1 <- glm(native~area,fam=poisson,weight=wt))
z1$aic/2
print(z1a <- glm(native~area+I(area^2),fam=poisson,weight=wt))
z1a$aic/2
print(z2 <- glm(native~elevation,fam=poisson,weight=wt))
z2$aic/2
print(z2a <- glm(native~elevation+I(elevation^2),fam=poisson,weight=wt))
z2a$aic/2
print(z3 <- glm(native~nearest,fam=poisson,weight=wt))
z3$aic/2
print(z4 <- glm(native~santacruz,fam=poisson,weight=wt))
z4$aic/2
print(z5 <- glm(native~adjacent,fam=poisson,weight=wt))
z5$aic/2

print(z6 <- glm(native~area+elevation+I(area^2)+I(elevation^2/10000)
	+area:elevation,fam=poisson,weight=wt))
z6$aic/2
print(u7 <- rs2(native,area,elevation,fam=poisson,weight=wt))
u7$aic/2
print(z7 <- glm(native~log(area)+elevation+I(log(area)^2)+I(elevation^2)
	+log(area):elevation,fam=poisson,weight=wt))
z7$aic/2+2
rm(z0,zf,z1,z1a,z2,z2a,z3,z4,z5)

mu2 <- function(p) exp(p[1]+p[2]*log(area)+p[3]*elevation+p[4]*log(area)^2+
	p[5]*elevation^2/10000+p[6]*log(area)*elevation)
shape <- function(p,mu) p[1]+log(mu)
# add 2 to AICs for estimated power parameters
gnlr(native,"negative bin",pmu=c(2.63,0.3,-0.0003,-0.075,-0.031,0.001),
	mu=mu2,psh=0.32,shape=shape,wt=wt,shfn=T)
exp(0.09183)
gnlr(native,"negative bin",pmu=c(2.67,0.3,-0.0003,-0.08,-0.03,0.001),
	mu=mu2,psh=2,wt=wt)

if(interactive()){
x1 <- (as.numeric(gl(51,1,2601))-1)*100
x2 <- (as.numeric(gl(51,51,2601))-1)*40
ff <- function(x1,x2) 2.64+0.24*log(x1)+0.00084*x2-0.078*log(x1)^2-
	0.0000037*x2^2+0.0011*log(x1)*x2
postscript(file="galarsc.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
contour(seq(0,5000,by=100),seq(0,2000,by=40),matrix(ff(x1,x2),nrow=51),nlev=20)
title(xlab="Area",ylab="Elevation")
dev.off()
}

print(u9 <- rs3(native,area,elevation,santacruz,p=c(-1,0.8,1),fam=poisson,
	weight=wt))
u9$aic/2
print(u10 <- glm(native~I(1/area)+elevation+I(santacruz^2)+I(area^-2)+
	I(elevation^2)+I(santacruz^4)+I(1/area):elevation+I(1/area):
	I(santacruz^2)+elevation:I(santacruz^2),fam=poisson,weight=wt))
u10$aic/2+3
print(u11 <- glm(native~I(1/area)+elevation+santacruz+I(area^-2)+
	I(elevation^2)+I(santacruz^2)+I(1/area):elevation+I(1/area):
	santacruz+elevation:santacruz,fam=poisson,weight=wt))
u11$aic/2+3

area3 <- 1/(area[wt==1])
area4 <- area3^2
santa <- santacruz[wt==1]
santa2 <- santa^2
mu3 <- function(p) exp(p[1]+p[2]/area+p[3]*elevation+p[4]*santacruz+
	p[5]/area^2+p[6]*elevation^2/10000+p[7]*santacruz^2/10000+
	p[8]/area*elevation+p[9]/area*santacruz+
	p[10]*elevation*santacruz/10000)
# add 3 to AICs for estimated power parameters
gnlr(native,"negative bin",pmu=c(2.59,0.43,0.0032,0.0045,-0.001,-0.01,
	-0.1,-0.0056,-0.0044,-0.1),mu=mu3,psh=0.1,shape=shape,wt=wt,shfn=T,
	iter=200)

# add 2 to AICs for estimated power parameters
gnlr(native,"double Poisson",pmu=c(2.67,0.24,-0.00004,-0.08,-0.04,0.0012),
	psh=-0.7,mu=mu2,wt=wt)
gnlr(native,"mult Poisson",pmu=c(2.62,0.25,-0.00004,-0.076,-0.034,0.001),
	psh=0.001,mu=mu2,wt=wt)
gnlr(native,"Consul",pmu=c(2.67,0.24,-0.00004,-0.08,-0.04,0.0012),
	psh=0.01,mu=mu2,wt=wt)
gnlr(native,"gamma count",pmu=c(2.67,0.24,-0.00004,-0.08,-0.04,0.0012),
	psh=0.01,mu=mu2,wt=wt)
nat <- native[wt==1]
area1 <- log(area[wt==1])
area2 <- area1^2
el <- elevation[wt==1]
el2 <- el^2
summary(zmm <- glmm(nat~area1+el+area2+el2+area1:el,fam=poisson,nest=1:24,
	points=5))
zmm$aic/2+2
gnlmm(native,"Poisson",mu=mu2,pmu=c(2.96,0.177,0.000016,
	-0.088,-0.0416,0.00128),psd=0.685,nest=1:30,points=7,wt=wt)
