library(repeated)
library(gnlm)

data <- read.table("offsprin.dat",skip=8)
attach(data)
y <- cbind(c(V2,V4),c(V1,V3)-c(V2,V4))
treat <- gl(2,16,32)

print(z0 <- glm(y~treat,fam=binomial))
z0$aic/2

gnlr(y,"binomial",pmu=1.4,mu=~1/(1+exp(-a)))
gnlr(y,"beta binomial",pmu=1.4,mu=~1/(1+exp(-a)),psh=1)
gnlr(y,"double binomial",pmu=2,mu=~1/(1+exp(-a)),psh=-1.4)
gnlr(y,"mult binomial",pmu=0.5,mu=~1/(1+exp(-a)),psh=-0.2)
print(z <- glmm(y~1,nest=1:32,family=binomial,points=14))
z$aic/2

mu <- function(p,linear) exp(linear)/(1+exp(linear))
gnlr(y,"binomial",pmu=z0$coef,mu=mu,linear=~treat)
gnlr(y,"beta binomial",pmu=z0$coef,mu=mu,linear=~treat,psh=1)
gnlr(y,"double binomial",pmu=z0$coef,mu=mu,linear=~treat,psh=0)
gnlr(y,"mult binomial",pmu=z0$coef,mu=mu,linear=~treat,psh=0)
print(z <- glmm(y~treat,nest=1:32,family=binomial,points=14))
z$aic/2

gnlr(y,"beta binomial",pmu=2,mu=~1/(1+exp(-a)),shape=~treat,psh=c(2,1))
gnlr(y,"double binomial",pmu=2.2,mu=~1/(1+exp(-a)),shape=~treat,
	psh=c(-0.24,-1.8))
gnlr(y,"mult binomial",pmu=2,mu=~1/(1+exp(-a)),shape=~treat,psh=c(0,0))

gnlr(y,"beta binomial",pmu=z0$coef,mu=mu,linear=~treat,shape=~treat,psh=c(2,1))
exp(2.175)/(1+exp(2.175))
exp(1.05)/(1+exp(1.05))
1/(1+exp(3.880))
1/(1+exp(0.75))
gnlr(y,"double binomial",pmu=z0$coef,mu=mu,linear=~treat,shape=~treat,
	psh=c(0,0))
gnlr(y,"mult binomial",pmu=z0$coef,mu=mu,linear=~treat,shape=~treat,psh=c(0,0))
y1 <- cbind(V2,V1-V2)
print(z1 <- glmm(y1~1,nest=1:16,family=binomial,points=14))
y2 <- cbind(V4,V3-V4)
print(z2 <- glmm(y2~1,nest=1:16,family=binomial,points=14))
(z1$aic+z2$aic)/2

fm <- function(p) {
   p[1] <- exp(p[1])/(1+exp(p[1]))
   p[2] <- exp(p[2])/(1+exp(p[2]))
   p[3] <- exp(p[3])/(1+exp(p[3]))
   -sum(log(choose(V3,V4)*(p[3]*p[1]^V4*(1-p[1])^(V3-V4))+
	(1-p[3])*p[2]^V4*(1-p[2])^(V3-V4)))}
print(z1 <- nlm(fm,c(0,2,-1)))
print(z2 <- gnlr(cbind(V2,V1-V2),"binomial",pmu=1.4,mu=~1/(1+exp(-a))))
gnlr(cbind(V4,V3-V4),"binomial",pmu=1.4,mu=~1/(1+exp(-a)))
z1$minimum+3+z2$maxlike+1

if(interactive()){
bb <- function(mu,psi,n) {
	t <- exp(psi)*mu
	u <- exp(psi)*(1-mu)
	exp(lbeta((0:n)+t,(n:0)+u)-lbeta(t,u)+lchoose(n,0:n))}
db <- function(mu,psi,n) {
	m <- mu
	s <- exp(psi)
	t <- s*(0:n)
	u <- s*(n:0)
	y1 <- c(1,1:n)
	y2 <- c(n:1,1)
	db <- exp((t+u)*log(n)+t*log(m/y1)+u*log((1-m)/y2)+
		lchoose(n,0:n)+y1*log(y1)+y2*log(y2)-n*log(n))
	db/sum(db)}
mb <- function(mu,psi,n) {
	mb <- exp((0:n)*log(mu)+(n:0)*log(1-mu)+(0:n)*(n:0)*psi+lchoose(n,0:n))
	mb/sum(mb)}
nb <- function(mu,psi,n) {
	quad <- gauss.hermite(10)
	nb <- rep(0,n+1)
	for(y in 0:n){
		mu1 <- exp(mu+psi*quad[,1])
		mu1 <- mu1/(1+mu1)
		nb[y+1] <- sum(exp(log(quad[,2])+lchoose(n,y)+y*log(mu1)+(n-y)*log(1-mu1)))}
	nb}
#for article
#postscript("offsprin.eps",height=10)
postscript("offsprin.eps",height=5)
par(mfrow=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(0:10,dbinom(0:10,10,0.9),type="l",xlab=expression(y),ylab=expression(pi),
	main="Control",ylim=c(0,0.4))
lines(0:10,bb(0.9,3.88,10),lty=2)
lines(0:10,db(0.9,-0.24,10),lty=3)
lines(0:10,mb(0.815,-0.096,10),lty=4)
lines(0:10,nb(2.2644,0.4839,10))
points(0:10,nb(2.2644,0.4839,10),pch=20)
z1 <- hist(V2/V1,breaks=seq(0,1,by=0.05),plot=F)
rect(seq(0,9.5,by=0.5),0,seq(0.5,10,by=0.5),z1$counts/10)

plot(0:10,dbinom(0:10,10,0.78),type="l",xlab=expression(y),ylab="",
	main="Treated",ylim=c(0,0.4))
lines(0:10,bb(0.74,0.75,10),lty=2)
lines(0:10,db(0.9,-2.02,10),lty=3)
lines(0:10,mb(0.56,-0.27,10),lty=4)
lines(0:10,nb(1.6890,1.7569,10))
points(0:10,nb(1.6890,1.7569,10),pch=20)
z2 <- hist(V4/V3,breaks=seq(0,1,by=0.05),plot=F)
rect(seq(0,9.5,by=0.5),0,seq(0.5,10,by=0.5),z2$counts/10)
dev.off()
}
