library(gnlm)
library(repeated)

sole <- read.table("sole.dat",skip=5)
names(sole) <- c("sal","temp","h1","t1","h2","t2","h3","t3","h4","t4")
attach(sole)
sal <- rep(sal,4)
temp <- rep(temp,4)
sal2 <- sal^2
temp2 <- temp^2
st <- sal*temp
hatch <- c(h1,h2,h3,h4)
total <- c(t1,t2,t3,t4)
y <- cbind(hatch,total-hatch)
y1 <- cbind(total-hatch,hatch)
mu <- function(p,linear) exp(linear)/(1+exp(linear))

-sum(lchoose(total,hatch)+hatch*log(hatch)+(total-hatch)*
	log(total-hatch)-total*log(total))
-sum(lchoose(total,hatch)+hatch*log(hatch)+(total-hatch)*
	log(total-hatch)-total*log(total))+length(total)
p.i <- (h1+h2+h3+h4)/(t1+t2+t3+t4)
p.i[16] <- p.i[17] <- (h1[16]+h2[16]+h3[16]+h4[16]+h1[17]+
	h2[17]+h3[17]+h4[17])/
	(t1[16]+t2[16]+t3[16]+t4[16]+t1[17]+t2[17]+t3[17]+t4[17])
-sum(lchoose(total,hatch)+hatch*log(p.i)+(total-hatch)*log(1-p.i))
-sum(lchoose(total,hatch)+hatch*log(p.i)+(total-hatch)*log(1-p.i))+length(h1)

# untransformed variables

print(u0 <- glm(y~sal+sal2+temp+temp2+st,family=binomial))
u0$aic/2
print(u0a <- glm(y1~sal+sal2+temp+temp2+st,family=binomial(link=cloglog)))
print(u0b <- glm(y~sal+sal2+temp+temp2+st,family=binomial(link=cloglog)))
print(u1 <- glm(y~as.factor(sal)*as.factor(temp),family=binomial))
u1$aic/2

print(z1 <- gnlr(y,pmu=c(-13,0.4,-0.01,2.4,-0.15,0.01),dist="binomial",
	mu=mu,linear=~sal+sal2+temp+temp2+st))

ind <- c(1:16,16,17)
ind <- as.factor(rep(ind,4))
print(z2f <- gnlr(y,pmu=c(-0.85,3,1.58,-0.3,3.28,2.12,-3.4,2.37,2,0.5,0.31,
	1.74,0.45,2.78,2.9,3,2.5),psh=4.2,dist="beta binomial",mu=mu,
	linear=~ind))
1/(1+exp(z2f$coef[18]))

print(z2 <- gnlr(y,pmu=c(-13,0.4, -0.01, 2.4,-0.15, 0.01),psh=4,
	dist="beta binomial",mu=mu, linear=~sal+sal2+temp+temp2+st))
1/(1+exp(z2$coef[7]))

print(zdb2 <- gnlr(y,pmu=c(-13.07,0.405,-0.0099,2.41,-0.151,0.0115),psh=-3.45,
	dist="double binomial",mu=mu, linear=~sal+sal2+temp+temp2+st))

print(z3 <- gnlr(y,pmu=c(-13,0.4, -0.01, 2.4,-0.15,0.01),
	psh=c(3.8,-0.1,-0.1),dist="beta binomial",mu=mu,
	linear=list(~sal+sal2+temp+temp2+st,~sal+sal2),stepmax=1))

print(z4 <- gnlr(y,pmu=c(-13,0.4, -0.01, 2.4,-0.15, 0.01),psh=c(-1,-0.53,0.03),
	dist="beta binomial",mu=mu,
	linear=list(~sal+sal2+temp+temp2+st,~temp+temp2),stepmax=1))

print(z5 <- gnlr(y,pmu=c(-11.98,0.39, -0.0094, 2.10,-0.137, 0.01),
	psh=c(3.92,-0.022,-0.0044,-0.012,-0.032,0.026),
	dist="beta binomial",mu=mu,linear=list(~sal+sal2+temp+temp2+st,
	~sal+sal2+temp+temp2+st),stepmax=3))

if(interactive()){
# logit link
p <- z5$coefficients
#probability
fp1 <- function(x1,x2) {
	t<-exp(p[1]+p[2]*x1+p[3]*x1^2+p[4]*x2+p[5]*x2^2+p[6]*x1*x2)
	t/(1+t)}
zz1p <- matrix(nrow=26,ncol=33)
for (i in 1:26) for (j in 1:33) {
	x1 <- (i+14)
	x2 <- j/4+3.75
	zz1p[i,j] <- fp1(x1,x2)}
contour((15:40),seq(4,12,by=0.25),zz1p)
title(main="Probability",xlab="Salinity",ylab="Temperature")
fp1(2.5,9)
aa <- -c(p[2],p[4])
bb <- matrix(c(2*p[3],p[6],p[6],2*p[5]),nrow=2)
solve(bb,aa)
range(zz1p)

#dispersion
fd1 <- function(x1,x2)
	exp(p[7]+p[8]*x1+p[9]*x1^2+p[10]*x2+p[11]*x2^2+p[12]*x1*x2)
zz1d <- matrix(nrow=26,ncol=33)
for (i in 1:26) for (j in 1:33) {
	x1 <- (i+14)
	x2 <- j/4+3.75
	zz1d[i,j] <- fd1(x1,x2)}
contour((15:40),seq(4,12,by=0.25),zz1d)
title(main="Dispersion",xlab="Salinity",ylab="Temperature")
fd1(2.6,9)
range(zz1d)

#correlation
fc1 <- function(x1,x2)
	1/(1+exp(p[7]+p[8]*x1+p[9]*x1^2+p[10]*x2+p[11]*x2^2+p[12]*x1*x2))
zz1c <- matrix(nrow=26,ncol=33)
for (i in 1:26) for (j in 1:33) {
	x1 <- (i+14)
	x2 <- j/4+3.75
	zz1c[i,j] <- fc1(x1,x2)}
contour((15:40),seq(4,12,by=0.25),zz1c)
title(main="Correlation",xlab="Salinity",ylab="Temperature")
fc1(2.6,9)
range(zz1c)

#dispersion
fd1a <- function(x1,x2)
	exp(p[7]+p[8]*x1+p[9]*x1^2+p[10]*x2+p[11]*x2^2+p[12]*x1*x2)
zz1da <- matrix(nrow=26,ncol=33)
for (i in 1:26) for (j in 1:33) {
	x1 <- (i+14)
	x2 <- j/4+3.75
	zz1da[i,j] <- fd1a(x1,x2)}
contour((15:40),seq(4,12,by=0.25),zz1da)
title(main="Dispersion",xlab="Salinity",ylab="Temperature")
fd1a(2.6,9)
aa <- -c(p[8],p[10])
bb <- matrix(c(2*p[9],p[12],p[12],2*p[11]),nrow=2)
solve(bb,aa)
range(zz1da)

#correlation
fc1a <- function(x1,x2)
	1/(1+exp(p[7]+p[8]*x1+p[9]*x1^2+p[10]*x2+p[11]*x2^2+p[12]*x1*x2))
zz1ca <- matrix(nrow=26,ncol=33)
for (i in 1:26) for (j in 1:33) {
	x1 <- (i+14)
	x2 <- j/4+3.75
	zz1ca[i,j] <- fc1a(x1,x2)}
contour((15:40),seq(4,12,by=0.25),zz1ca)
title(main="Correlation",xlab="Salinity",ylab="Temperature")
fc1a(2.6,9)
range(zz1ca)
}

# transformed variables

print(summary(s1 <- rs2(y,sal,temp,power=c(0.2,0.2),family=binomial)))
s1$aic/2

s <- sal^0.2
t <- temp^0.2
s2 <- s^2
t2 <- t^2
stt <- s*t

glm(y~s+s2+t+t2+stt,family=binomial)
glm(y1~s+s2+t+t2+stt,family=binomial(link=cloglog))
glm(y~s+s2+t+t2+stt,family=binomial(link=cloglog))

print(znm <- glmm(y~s+s2+t+t2+stt,family=binomial,nest=1:72,points=5))
znm$aic/2
# underflow:
#glmm(y~s+s2+t+t2+stt,family=binomial,nest=rep(1:18,4),points=3)

print(z1t <- gnlr(y,pmu=c(-270,110,-37,234,-88,18),dist="binomial",
	mu=mu,linear=~s+s2+t+t2+stt))

p <- z1t$coefficients
aa <- -c(p[2],p[4])
bb <- matrix(c(2*p[3],p[6],p[6],2*p[5]),nrow=2)
solve(bb,aa)^5

if(interactive()){
#probability
fp0 <- function(x1,x2) {
	t<-exp(p[1]+p[2]*x1^.2+p[3]*x1^.4+p[4]*x2^.2+p[5]*x2^.4+
		p[6]*x1^.2*x2^.2)
	t/(1+t)}
zz0p <- matrix(nrow=26,ncol=31)
for (i in 0:25) for (j in 0:30) zz0p[i,j] <- fp0(2*i,j/2)
#postscript(file="fishrsc.eps",width=5,height=5)
plot(0,0,type="n",xlim=c(0,50),ylim=c(0,15),xlab="Salinity",ylab="Temperature")
contour(as.real(seq(0,50,by=2)),seq(0,15,by=0.5),zz0p,add=T)
fp0(22.03,8.32)
range(zz0p)
}
print(z2t <- gnlr(y,pmu=c(-270,109.4,-36.9,232.4,-87,18),psh=3.47,
	dist="beta binomial",mu=mu, linear=~s+s2+t+t2+stt,stepmax=0.1))
1/(1+exp(z2t$coef[7]))

p <- z2t$coefficients
aa <- -c(p[2],p[4])
bb <- matrix(c(2*p[3],p[6],p[6],2*p[5]),nrow=2)
solve(bb,aa)^5

if(interactive()){
#probability
fp0 <- function(x1,x2) {
	t<-exp(p[1]+p[2]*x1^.2+p[3]*x1^.4+p[4]*x2^.2+p[5]*x2^.4+
		p[6]*x1^.2*x2^.2)
	t/(1+t)}
zz0p <- matrix(nrow=26,ncol=31)
for (i in 0:25) for (j in 0:30) zz0p[i,j] <- fp0(2*i,j/2)
postscript(file="fishrsc.eps",width=5,height=5)
plot(0,0,type="n",xlim=c(0,50),ylim=c(0,15),xlab="Salinity",ylab="Temperature")
contour(as.real(seq(0,50,by=2)),seq(0,15,by=0.5),zz0p,add=T)
fp0(22.05,8.37)
range(zz0p)
}

print(z3ta <- gnlr(y,pmu=c(-275,109,-36.8,231,-86.4,18),psh=-2.85,
	dist="double binomial",mu=mu,linear=~s+s2+t+t2+stt))

print(z3tb <- gnlr(y,pmu=c(-274.3,109.07,-36.8,230.7,-86.58,18),psh=-0.00025,
	dist="mult binomial",mu=mu,linear=~s+s2+t+t2+stt))

print(z4t <- gnlr(y,pmu=c(-265.05,107.1,-35.45,220.16,-82.05,16.3),
	psh=c(4.01,0.076,-0.0058,0.0252,-0.03,0.0195),
	dist="beta binomial",mu=mu,
	linear=list(~s+s2+t+t2+stt,~sal+sal2+temp+temp2+st)))

print(z5t <- gnlr(y,pmu=c(-260,106.79,-34.12,221,-80.12,13.058),
	psh=c(5.44,-0.219,-1.176,0.36,0.839,0.124),dist="beta binomial",mu=mu,
	linear=list(~s+s2+t+t2+stt,~s+s2+t+t2+stt)))

print(z6t <- gnlr(y,pmu=c(-265.1,106.6,-34.13,220.5,-80.06,13.22),
	psh=c(5.694,-0.2,-1.166,0.925,0.129),dist="beta binomial",mu=mu,
	linear=list(~s+s2+t+t2+stt,~s+s2+t2+stt)))

print(z7t <- gnlr(y,pmu=c(-264.95,106.46,-34.16,220.46,-80.13,13.36),
	psh=c(5.5,-1.22,0.925,0.129),dist="beta binomial",mu=mu,
	linear=list(~s+s2+t+t2+stt,~s2+t2+stt)))

print(z8t <- gnlr(y,pmu=c(-266.12,107.1,-34.37,221.28,-80.45,13.45),
	psh=c(5.74,-1.15,0.87),dist="beta binomial",mu=mu,
	linear=list(~s+s2+t+t2+stt,~s2+t2)))

print(z9t <- gnlr(y,pmu=c(-266,107.4,-34.5,220.6,-80.2,13.4),psh=c(5.5,-1.18),
	dist="beta binomial",mu=mu,linear=list(~s+s2+t+t2+stt,~s2)))

print(z10t <- gnlr(y,pmu=c(-264.9,107,-35.48,220.1,-82.14,16.47),
	psh=c(4.12,0.076,-0.0058,-0.029,0.02),dist="beta binomial",mu=mu,
	linear=list(~s+s2+t+t2+stt,~sal+sal2+temp2+st)))

print(z11t <- gnlr(y,pmu=c(-264.34,108.62,-35.63,217.26,-80.7,15.73),
	psh=c(5.02,-0.0045,-0.0293,0.02),dist="beta binomial",mu=mu,
	linear=list(~s+s2+t+t2+stt,~sal2+temp2+st)))

if(interactive()){
p <- z11t$coefficients
#probability
fp5 <- function(x1,x2) {
	t<-exp(p[1]+p[2]*x1^.2+p[3]*x1^.4+p[4]*x2^.2+p[5]*x2^.4+p[6]*x1^.2*x2^.2)
	t/(1+t)}
zz5p <- matrix(nrow=31,ncol=33)
for (i in 1:31) for (j in 1:33) zz5p[i,j] <- fp5((i+9),j/4+3.75)
fp5(2.4,8.5)
range(zz5p)

#correlation
fc5 <- function(x1,x2)
	1/(1+exp(p[7]+p[8]*x1^2+p[9]*x2^2+p[10]*x1*x2))
zz5c <- matrix(nrow=31,ncol=33)
for (i in 1:31) for (j in 1:33) zz5c[i,j] <- fc5((i+9),j/4+3.75)
fc5(1.5,7.5)
range(zz5c)

postscript(file="sole2.eps",height=5)
par(mfcol=c(1,2))
contour((10:40),seq(4,12,by=0.25),zz5p)
points(sal[1:18],temp[1:18],pch=20)
title(xlab="Salinity",ylab="Temperature")
contour((10:40),seq(4,12,by=0.25),zz5c)
points(sal[1:18],temp[1:18],pch=20)
title(xlab="Salinity",ylab="")
}

#print(z11tmb <- gnlr(y,pmu=c(-274.3,109,-36.8,230.8,-86.6,18),
#	psh=c(-0.00015,-0.0000002,-0.00000002,-0.0000002),dist="mult binomial",
#	mu=mu,linear=list(~s+s2+t+t2+stt,~sal2+temp2+st)))
print(z11tdb <- gnlr(y,pmu=c(-275,109,-36.8,231,-86.4,18.0),
	psh=c(-2.85,0,0,0),dist="double binomial",mu=mu,
	linear=list(~s+s2+t+t2+stt,~sal2+temp2+st)))
