library(gnlm)
library(repeated)

sole <- read.table("sole.dat",skip=5)
names(sole) <- c("sal","temp","h1","t1","h2","t2","h3","t3","h4","t4")
attach(sole)
sal <- rep(sal,4)
temp <- rep(temp,4)
sal2 <- sal^2
temp2 <- temp^2
st <- sal*temp
hatch <- c(h1,h2,h3,h4)
total <- c(t1,t2,t3,t4)
y <- cbind(hatch,total-hatch)
y1 <- cbind(total-hatch,hatch)
mu <- function(p,linear) exp(linear)/(1+exp(linear))

-sum(lchoose(total,hatch)+hatch*log(hatch)+(total-hatch)*
	log(total-hatch)-total*log(total))+length(total)
p.i <- (h1+h2+h3+h4)/(t1+t2+t3+t4)
p.i[16] <- p.i[17] <- (h1[16]+h2[16]+h3[16]+h4[16]+h1[17]+
	h2[17]+h3[17]+h4[17])/
	(t1[16]+t2[16]+t3[16]+t4[16]+t1[17]+t2[17]+t3[17]+t4[17])
-sum(lchoose(total,hatch)+hatch*log(p.i)+(total-hatch)*log(1-p.i))+length(h1-1)

print(u0 <- glm(y~sal+sal2+temp+temp2+st,family=binomial))
u0$aic/2
print(u1 <- glm(y~as.factor(sal)*as.factor(temp),family=binomial))
u1$aic/2
print(z1 <- gnlr(y,pmu=c(-13,0.4,-0.01,2.4,-0.15,0.01),dist="binomial",
	mu=mu,linear=~sal+sal2+temp+temp2+st))

ind <- as.factor(rep(c(1:16,16,17),4))
print(z2f <- gnlr(y,pmu=c(-0.85,3,1.58,-0.3,3.28,2.12,-3.4,2.37,2,0.5,0.31,
	1.74,0.45,2.78,2.9,3,2.5),psh=4.2,dist="beta binomial",mu=mu,
	linear=~ind))
1/(1+exp(z2f$coef[18]))
print(z2 <- gnlr(y,pmu=c(-13,0.4, -0.01, 2.4,-0.15, 0.01),psh=4,
	dist="beta binomial",mu=mu, linear=~sal+sal2+temp+temp2+st))
1/(1+exp(z2$coef[7]))


# transformed variables
print(summary(s1 <- rs2(y,sal,temp,power=c(0.2,0.2),family=binomial)))
s1$aic/2
s <- sal^0.2
t <- temp^0.2
s2 <- s^2
t2 <- t^2
stt <- s*t
print(z2t <- gnlr(y,pmu=c(-270,109.4,-36.9,232.4,-87,18),psh=3.47,
	dist="beta binomial",mu=mu, linear=~s+s2+t+t2+stt,stepmax=0.1))
1/(1+exp(z2t$coef[7]))

p <- z2t$coefficients
aa <- -c(p[2],p[4])
bb <- matrix(c(2*p[3],p[6],p[6],2*p[5]),nrow=2)
solve(bb,aa)^5

if(interactive()){
#probability
fp0 <- function(x1,x2) {
	t<-exp(p[1]+p[2]*x1^.2+p[3]*x1^.4+p[4]*x2^.2+p[5]*x2^.4+
		p[6]*x1^.2*x2^.2)
	t/(1+t)}
zz0p <- matrix(nrow=26,ncol=31)
for (i in 0:25) for (j in 0:30) zz0p[i,j] <- fp0(2*i,j/2)
postscript(file="fishrsc.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(0,0,type="n",xlim=c(0,50),ylim=c(0,15),xlab="Salinity",ylab="Temperature")
contour(as.double(seq(0,50,by=2)),seq(0,15,by=0.5),zz0p,add=T,
	levels=seq(0.1,0.9,by=0.1))
dev.off()
fp0(22.05,8.37)
range(zz0p,na.rm=T)
}

print(z3ta <- gnlr(y,pmu=c(-275,109,-36.8,231,-86.4,18),psh=-2.85,
	dist="double binomial",mu=mu,linear=~s+s2+t+t2+stt))
print(z3tb <- gnlr(y,pmu=c(-274.3,109.07,-36.8,230.7,-86.58,18),psh=-0.00025,
	dist="mult binomial",mu=mu,linear=~s+s2+t+t2+stt))
print(znm <- glmm(y~s+s2+t+t2+stt,family=binomial,nest=1:72,points=5))
znm$aic/2
print(z11t <- gnlr(y,pmu=c(-264.34,108.62,-35.63,217.26,-80.7,15.73),
	psh=c(5.02,-0.0045,-0.0293,0.02),dist="beta binomial",mu=mu,
	linear=list(~s+s2+t+t2+stt,~sal2+temp2+st)))
print(z11tdb <- gnlr(y,pmu=c(-275,109,-36.8,231,-86.4,18.0),
	psh=c(-2.85,0,0,0),dist="double binomial",mu=mu,
	linear=list(~s+s2+t+t2+stt,~sal2+temp2+st)))

if(interactive()){
p <- z11t$coefficients
#probability
fp5 <- function(x1,x2) {
	t<-exp(p[1]+p[2]*x1^.2+p[3]*x1^.4+p[4]*x2^.2+p[5]*x2^.4+p[6]*x1^.2*x2^.2)
	t/(1+t)}
zz5p <- matrix(nrow=26,ncol=31)
for (i in 0:25) for (j in 0:30) zz5p[i,j] <- fp5(2*i,j/2)
fp5(2.4,8.5)
range(zz5p,na.rm=T)

#correlation
fc5 <- function(x1,x2)
	1/(1+exp(p[7]+p[8]*x1^2+p[9]*x2^2+p[10]*x1*x2))
zz5c <- matrix(nrow=26,ncol=31)
for (i in 0:25) for (j in 0:30) zz5c[i,j] <- fc5(2*i,j/2)
fc5(1.5,7.5)
range(zz5c,na.rm=T)

postscript(file="sole2.eps",height=5)
par(mfcol=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(0,0,type="n",xlim=c(0,50),ylim=c(0,15),xlab="Salinity",ylab="Temperature")
contour(as.double(seq(0,50,by=2)),seq(0,15,by=0.5),zz5p,add=T,
	levels=seq(0.1,0.9,by=0.1))
points(sal[1:18],temp[1:18],pch=20)
plot(0,0,type="n",xlim=c(0,50),ylim=c(0,15),xlab="Salinity",ylab="")
contour(as.double(seq(0,50,by=2)),seq(0,15,by=0.5),zz5c,
	levels=seq(0.02,0.34,by=0.04),add=T)
points(sal[1:18],temp[1:18],pch=20)
dev.off()
}
