library(gnlm)

data <- read.table("chlamydia.dat",skip=3)
attach(data)

# V7 as gold standard
totalgs <- V2+V3+V4+V5+V6
totalgs1 <- as.factor(totalgs)
print(summary(zrgs1 <- glm(V1~(V2+V3+V4+V5+V6)*V7,family=poisson)))
zrgs1$fit
t2 <- tapply(zrgs1$fit,list(V2,V7),sum)
t(t2)/apply(t2,2,sum)
t3 <- tapply(zrgs1$fit,list(V3,V7),sum)
t(t3)/apply(t3,2,sum)
t4 <- tapply(zrgs1$fit,list(V4,V7),sum)
t(t4)/apply(t4,2,sum)
t5 <- tapply(zrgs1$fit,list(V5,V7),sum)
t(t5)/apply(t5,2,sum)
t6 <- tapply(zrgs1$fit,list(V6,V7),sum)
t(t6)/apply(t6,2,sum)
print(summary(zrgs2 <- glm(V1~(V2+V3+V4+V5+V6)*V7+totalgs1,family=poisson)))
zrgs2$fit
t2 <- tapply(zrgs2$fit,list(V2,V7),sum)
t(t2)/apply(t2,2,sum)
t3 <- tapply(zrgs2$fit,list(V3,V7),sum)
t(t3)/apply(t3,2,sum)
t4 <- tapply(zrgs2$fit,list(V4,V7),sum)
t(t4)/apply(t4,2,sum)
t5 <- tapply(zrgs2$fit,list(V5,V7),sum)
t(t5)/apply(t5,2,sum)
t6 <- tapply(zrgs2$fit,list(V6,V7),sum)
t(t6)/apply(t6,2,sum)

# ordinary Rasch model
total <- V2+V3+V4+V5+V6+V7
total1 <- as.factor(total)
total2 <- as.factor(ifelse(total==2|total==3|total==4,2,total))
print(summary(z0 <- glm(V1~V2+V3+V4+V5+V6+V7,family=poisson)))
print(summary(zr1 <- glm(V1~V2+V3+V4+V5+V6+V7+total1,family=poisson)))
zr1$fit
print(summary(zr2 <- glm(V1~V2+V3+V4+V5+V6+V7+total2,family=poisson)))
zr2$fit

# latent class model
likeb <- function(p){
	p <- exp(p)
	p <- p/(1+p)
	-sum(V1*log(p[1]*p[2]^V2*(1-p[2])^(1-V2)*p[3]^V3*(1-p[3])^(1-V3)*
	p[4]^V4*(1-p[4])^(1-V4)*p[5]^V5*(1-p[5])^(1-V5)*
	p[6]^V6*(1-p[6])^(1-V6)*p[7]^V7*(1-p[7])^(1-V7)+
	(1-p[1])*p[8]^V2*(1-p[8])^(1-V2)*p[9]^V3*(1-p[9])^(1-V3)*
	p[10]^V4*(1-p[10])^(1-V4)*p[11]^V5*(1-p[11])^(1-V5)*
	p[12]^V6*(1-p[12])^(1-V6)*p[13]^V7*(1-p[13])^(1-V7)))}
print(zlcb <- nlm(likeb,rep(0.5,13)))
(exp(zlcb$est)/(1+exp(zlcb$est)))[8:13]
(1-exp(zlcb$est)/(1+exp(zlcb$est)))[1:7]

likep <- function(p){
	 p[1] <- exp(p[1])/(1+exp(p[1]))
	 mu1 <-  exp(p[14]+p[2]*V2+p[3]*V3+p[4]*V4+p[5]*V5+p[6]*V6+p[7]*V7)
	 mu2 <-  exp(p[15]+p[8]*V2+p[9]*V3+p[10]*V4+p[11]*V5+p[12]*V6+p[13]*V7)
	 -sum(log(p[1]*exp(-mu1)*mu1^V1+(1-p[1])*exp(-mu2)*mu2^V1))}
print(zlcp <- nlm(likep,c(zlcb$est,0.16,-6.85)))
(exp(zlcp$est)/(1+exp(zlcp$est)))[8:13]
(1-exp(zlcp$est)/(1+exp(zlcp$est)))[1:7]

likepr <- function(p){
	 p[1] <- exp(p[1])/(1+exp(p[1]))
	 rasch <- (total==1)*p[16]+(total==2)*p[17]+(total==3)*p[18]+
		(total==4)*p[19]+(total==5)*p[20]
	 mu1 <- exp(p[14]+p[2]*V2+p[3]*V3+p[4]*V4+p[5]*V5+p[6]*V6+p[7]*V7+
		rasch)
	 mu2 <-  exp(p[15]+p[8]*V2+p[9]*V3+p[10]*V4+p[11]*V5+p[12]*V6+
		p[13]*V7+rasch)
	 -sum(log(p[1]*exp(-mu1)*mu1^V1+(1-p[1])*exp(-mu2)*mu2^V1))}
print(zlcpr <- nlm(likepr,c(zlcb$est,0.05,-6.81,8,2.7,0.6,-0.9,-1.1),stepmax=0.1))
(exp(zlcpr$est)/(1+exp(zlcpr$est)))[8:13]
(1-exp(zlcpr$est)/(1+exp(zlcpr$est)))[1:7]

# overdispersion
mu <- function(p,linear) exp(linear)
gnlr(V1,dist="Poisson",mu=mu,linear=~V2+V3+V4+V5+V6+V7,pmu=z0$coef)
gnlr(V1,dist="negative bin",mu=mu,linear=~V2+V3+V4+V5+V6+V7,pmu=z0$coef,psh=1)
gnlr(V1,dist="negative bin",mu=mu,linear=~(V2+V3+V4+V5+V6)*V7,pmu=zrgs1$coef,psh=1)
