library(gnlm)

data <- read.table("chlamydia.dat",skip=3)
attach(data)
v1 <- rep(0,64)
v1[1+V2+2*V3+4*V4+8*V5+16*V6+32*V7] <- V1
v2 <- codes(gl(2,1,64))-1
v3 <- codes(gl(2,2,64))-1
v4 <- codes(gl(2,4,64))-1
v5 <- codes(gl(2,8,64))-1
v6 <- codes(gl(2,16,64))-1
v7 <- codes(gl(2,32,64))-1

# V7 as gold standard
totalgs <- v2+v3+v4+v5+v6
totalgs1 <- as.factor(totalgs)
print(summary(zrgs1 <- glm(v1~(v2+v3+v4+v5+v6)*v7,family=poisson)))
zrgs1$fit
t2 <- tapply(zrgs1$fit,list(v2,v7),sum)
t(t2)/apply(t2,2,sum)
t3 <- tapply(zrgs1$fit,list(v3,v7),sum)
t(t3)/apply(t3,2,sum)
t4 <- tapply(zrgs1$fit,list(v4,v7),sum)
t(t4)/apply(t4,2,sum)
t5 <- tapply(zrgs1$fit,list(v5,v7),sum)
t(t5)/apply(t5,2,sum)
t6 <- tapply(zrgs1$fit,list(v6,v7),sum)
t(t6)/apply(t6,2,sum)
print(summary(zrgs2 <- glm(v1~(v2+v3+v4+v5+v6)*v7+totalgs1,family=poisson)))
zrgs2$fit
t2 <- tapply(zrgs2$fit,list(v2,v7),sum)
t(t2)/apply(t2,2,sum)
t3 <- tapply(zrgs2$fit,list(v3,v7),sum)
t(t3)/apply(t3,2,sum)
t4 <- tapply(zrgs2$fit,list(v4,v7),sum)
t(t4)/apply(t4,2,sum)
t5 <- tapply(zrgs2$fit,list(v5,v7),sum)
t(t5)/apply(t5,2,sum)
t6 <- tapply(zrgs2$fit,list(v6,v7),sum)
t(t6)/apply(t6,2,sum)

# ordinary Rasch model
total <- v2+v3+v4+v5+v6+v7
total1 <- as.factor(total)
total2 <- as.factor(ifelse(total==2|total==3|total==4,2,total))
print(summary(z0 <- glm(v1~v2+v3+v4+v5+v6+v7,family=poisson)))
print(summary(zr1 <- glm(v1~v2+v3+v4+v5+v6+v7+total1,family=poisson)))
zr1$fit
print(summary(zr2 <- glm(v1~v2+v3+v4+v5+v6+v7+total2,family=poisson)))
zr2$fit

# latent class model
likeb <- function(p){
	p <- exp(p)
	p <- p/(1+p)
	-sum(v1*log(p[1]*p[2]^v2*(1-p[2])^(1-v2)*p[3]^v3*(1-p[3])^(1-v3)*
	p[4]^v4*(1-p[4])^(1-v4)*p[5]^v5*(1-p[5])^(1-v5)*
	p[6]^v6*(1-p[6])^(1-v6)*p[7]^v7*(1-p[7])^(1-v7)+
	(1-p[1])*p[8]^v2*(1-p[8])^(1-v2)*p[9]^v3*(1-p[9])^(1-v3)*
	p[10]^v4*(1-p[10])^(1-v4)*p[11]^v5*(1-p[11])^(1-v5)*
	p[12]^v6*(1-p[12])^(1-v6)*p[13]^v7*(1-p[13])^(1-v7)))}
print(zlcb <- nlm(likeb,rep(0.5,13)))
(exp(zlcb$est)/(1+exp(zlcb$est)))[8:13]
(1-exp(zlcb$est)/(1+exp(zlcb$est)))[1:7]

likep <- function(p){
	 p[1] <- exp(p[1])/(1+exp(p[1]))
	 mu1 <-  exp(p[14]+p[2]*v2+p[3]*v3+p[4]*v4+p[5]*v5+p[6]*v6+p[7]*v7)
	 mu2 <-  exp(p[15]+p[8]*v2+p[9]*v3+p[10]*v4+p[11]*v5+p[12]*v6+p[13]*v7)
	 -sum(log(p[1]*exp(-mu1)*mu1^v1+(1-p[1])*exp(-mu2)*mu2^v1))}
print(zlcp <- nlm(likep,c(zlcb$est,0.16,-6.85)))
(exp(zlcp$est)/(1+exp(zlcp$est)))[8:13]
(1-exp(zlcp$est)/(1+exp(zlcp$est)))[1:7]

likepr <- function(p){
	 p[1] <- exp(p[1])/(1+exp(p[1]))
	 rasch <- (total==1)*p[16]+(total==2)*p[17]+(total==3)*p[18]+
		(total==4)*p[19]+(total==5)*p[20]
	 mu1 <- exp(p[14]+p[2]*v2+p[3]*v3+p[4]*v4+p[5]*v5+p[6]*v6+p[7]*v7+
		rasch)
	 mu2 <-  exp(p[15]+p[8]*v2+p[9]*v3+p[10]*v4+p[11]*v5+p[12]*v6+
		p[13]*v7+rasch)
	 -sum(log(p[1]*exp(-mu1)*mu1^v1+(1-p[1])*exp(-mu2)*mu2^v1))}
print(zlcpr <- nlm(likepr,c(zlcb$est,0.05,-6.81,8,2.7,0.6,-0.9,-1.1),stepmax=0.1))
(exp(zlcpr$est)/(1+exp(zlcpr$est)))[8:13]
(1-exp(zlcpr$est)/(1+exp(zlcpr$est)))[1:7]

# overdispersion
mu <- function(p,linear) exp(linear)
gnlr(v1,dist="Poisson",mu=mu,linear=~v2+v3+v4+v5+v6+v7,pmu=z0$coef)
gnlr(v1,dist="negative bin",mu=mu,linear=~v2+v3+v4+v5+v6+v7,pmu=z0$coef,psh=1)
gnlr(v1,dist="negative bin",mu=mu,linear=~(v2+v3+v4+v5+v6)*v7,pmu=zrgs1$coef,psh=1)
